@@ -3,7 +3,7 @@ from requests_oauthlib import OAuth1
 from flask import Markup
 
 class TwitterOEmbedder(object):
-    
+
     def __init__(self, app=None, cache=None, debug=None):
         if app and cache:
             self.init(app, cache, debug)
@@ -11,11 +11,13 @@ class TwitterOEmbedder(object):
         @app.context_processor
         def tweet_processor():
             @cache.memoize(timeout=60*60*24*356)
-            def oembed_tweet(tweet_id):
+            def oembed_tweet(tweet_id,
+                             access_token=app.config['TWITTER_ACCESS_TOKEN'],
+                             token_secret=app.config['TWITTER_TOKEN_SECRET']):
                 auth = OAuth1(app.config['TWITTER_CONSUMER_KEY'],
                               app.config['TWITTER_CONSUMER_SECRET'],
-                              app.config['TWITTER_ACCESS_TOKEN'],
-                              app.config['TWITTER_TOKEN_SECRET'])
+                              access_token,
+                              token_secret)
                 url = 'https://api.twitter.com/1.1/statuses/oembed.json'
                 r = requests.get(url, params={'id':tweet_id}, auth=auth)
                 try:
@@ -26,4 +28,4 @@ class TwitterOEmbedder(object):
                     else:
                         return ''
                 return tweet_html
-            return dict(oembed_tweet=oembed_tweet)
\ No newline at end of file
+            return dict(oembed_tweet=oembed_tweet)
